<?php
namespace Controllers;

use Psr\Http\Message\ResponseInterface as Response;
use Psr\Http\Message\ServerRequestInterface as Request;
use Slim\Views\PhpRenderer;

class GoogleController extends Controller {

    public function singleSignOn(Request $request, Response $response): Response {
        $params   = $request->getQueryParams();
        $callback = (string)($params['callback'] ?? '');
        $scopes   = [
            'email',
            'profile',
        ];

        $callbackUrl = $this->getBasicCallbackUrl($request) . '?callback=' . $callback;

        $url = $this->service()->getAuthUrl(join(' ', $scopes), $callbackUrl, 'online');

        return $response->withHeader('Location', $url)->withStatus(302);
    }

    public function callback(Request $request, Response $response): Response {
        $renderer = new PhpRenderer(__DIR__ . '/../templates');

        return $renderer->render($response, 'GoogleCallback.php');
    }

    public function faxProfileAuth(Request $request, Response $response): Response {
        $params   = $request->getQueryParams();
        $callback = (string)($params['callback'] ?? '');

        $scopes    = [
            'https://www.googleapis.com/auth/userinfo.profile',
            'https://www.googleapis.com/auth/userinfo.email',
            'https://mail.google.com/',
        ];

        $callbackUrl = $this->getBasicCallbackUrl($request) . '?callback=' . $callback;

        $url = $this->service()->getAuthUrl(join(' ', $scopes), $callbackUrl);

        return $response->withHeader('Location', $url)->withStatus(302);
    }

    private function getBasicCallbackUrl(Request $request): string {
        return sprintf('%s://%s/api/Google/Callback/', $request->getUri()->getScheme(), $request->getUri()->getHost());
    }

    private function service(): \GoogleAPI {
        return \GoogleAPI::getInstance();
    }
}
