<?php
namespace Controllers;

use Psr\Http\Message\ResponseInterface as Response;
use Psr\Http\Message\ServerRequestInterface as Request;
use Slim\Views\PhpRenderer;

class Microsoft extends Controller {

    public function singleSignOn(Request $request, Response $response) {
        $params    = $request->getQueryParams();
        $callback  = (string)($params['callback'] ?? '');
        $isMsTeams = (int)($params['msTeams'] ?? 0);
        $scopes    = [
                         'openid',
                         'profile',
                         'https://outlook.office.com/Contacts.Read',
                    ];

        $callbackUrl = $this->getBasicCallbackUrl($request) . '?msTeams=' . $isMsTeams . '&callback=' . $callback;

        $url = $this->serviceOffice365()->getAuthUrl(join(' ', $scopes), urlencode($callbackUrl), 'online');

        return $response->withHeader('Location', $url)->withStatus(302);
    }

    public function callback(Request $request, Response $response) {
        $renderer = new PhpRenderer(__DIR__ . '/../templates');

        return $renderer->render($response, 'MicrosoftCallback.php');
    }

    public function faxProfileAuth(Request $request, Response $response): Response {
        $params    = $request->getQueryParams();
        $callback  = (string)($params['callback'] ?? '');

        $scopes    = [
            'openid',
            'profile',
            'email',
            'offline_access',
            'https://outlook.office.com/IMAP.AccessAsUser.All',
            'https://outlook.office.com/POP.AccessAsUser.All',
            'https://outlook.office.com/Mail.Read',
        ];

        $callbackUrl = $this->getBasicCallbackUrl($request) . '?callback=' . $callback;

        $url = $this->serviceOffice365()->getAuthUrl(join(' ', $scopes), urlencode($callbackUrl));

        return $response->withHeader('Location', $url)->withStatus(302);
    }

    private function serviceOffice365(): \Microsoft\Office365 {
        return $this->getContainer()->get(\Microsoft\Office365::class);
    }

    private function getBasicCallbackUrl($request): string {
        return sprintf('%s://%s/api/Microsoft/Callback/', $request->getUri()->getScheme(), $request->getUri()->getHost());
    }
}
