<?php
declare(strict_types=1);

use PHPGangsta_GoogleAuthenticator as GoogleAuthenticator;
use Wildix\HttpSecurity\Service;
use Wildix\Slim\Middleware\CorsMiddleware;

// phpcs:disable PSR1.Classes.ClassDeclaration.MissingNamespace

/**
 * Class DiConfig
 */
final class DiConfig implements \Wildix\DependencyInjection\ConfigInterface {

    public static function configure(\Wildix\DependencyInjection\Container $container): void {
        $container->singleton(
            \Syslog::class . ':SSLCertificateRenewal',
            static function () {
                return new \Syslog('SSLCertificateRenewal', \Syslog::DEBUG);
            }
        );

        $container->singleton(
            GoogleAuthenticator::class,
            static function () {
                return new GoogleAuthenticator();
            }
        );

        $container->singleton(
            \WMS_Ldap::class,
            function () {
                return \WMS_Ldap::getInstance();
            }
        );

        $container->singleton(
            User::class,
            function () {
                return User::getInstance();
            }
        );

        $container->singleton(
            CorsMiddleware::class,
            function () use ($container) {
                return new CorsMiddleware($container->get(Service::class));
            }
        );

        $container->singleton(
            \WMS_Permissions::class,
            static function (): \WMS_Permissions {
                return \WMS_Permissions::getInstance();
            }
        );
    }
}

// phpcs:enable PSR1.Classes.ClassDeclaration.MissingNamespace
